# SnakeScan
![PyPI version](https://badge.fury.io/py/SnakeScan.svg)
![Requires-python](https://img.shields.io/badge/requires--python-3.7+-red)
![License](https://img.shields.io/badge/License-MIT-blue.svg)
 ```
import SnakeScan
SnakeScan.run()
```
## Help
- -l  need internet to view public ip you device
- -t threading port search
- -i information about host
- -help in host /-help port in host
- -check [host] scan subnet in ip
- exit in host or port off script
## Added class Watcher:
 ```
 for SnakeScan import Watcher
 Watcher(host:str,port:int)
 ```
 ## Added multiple use Watcher:
 ```
 from SnakeScan import Watcher
 ports=[53,80,100,160]
 for i in range(len(ports)):
 Watcher("127.0.0.1",ports[i])
 ```
## Added CLI command line use snake or Snake
```
usage: snake [-h] [-sp] [-v] [-i] [-p PORTS] [-t] [-ch]
             [-l]
             [host]

Snake - It's a command line module SnakeScan. Use him for
more fast starting

positional arguments:
  host

options:
  -h, --help         show this help message and exit
  -sp, --speed       speed scan
  -v, --version      version
  -i, --info         ip info
  -p, --ports PORTS  range ports to scan host
  -t, --thread       fast scan
  -ch, --check       scan subnet
  -l, --local        view you public ip - need internet
```
## Attributes
```
--p:snake -p 80,443,3437,20-1000
--p:[20]-1000 will start from [21]-[1000]
## Added Info about ipv6
```
snake 2001:db8:: -i or snake [2001:4860:4860::8888] -i
```